@@ -57,199 +57,6 @@ var network = {
       return connection;
   },
   
-  // prepare and patch OAuth2 object
-  getOAuthObj: function(_uri, configObject = null) {
-    let uri = _uri;
-    
-    // if _uri input is not yet an uri, try to get one
-    try {
-      if (!_uri.spec) 
-        uri = Services.io.newURI(_uri);
-    } catch (e) {
-      Components.utils.reportError(e);
-      return null;
-    }
-
-    let config = {};
-    switch (uri.host) {
-      case "apidata.googleusercontent.com":
-      case "www.googleapis.com":
-        config = {
-          base_uri : "https://accounts.google.com/o/",
-          //redirect_uri : "urn:ietf:wg:oauth:2.0:oob:auto",
-          scope : "https://www.googleapis.com/auth/carddav https://www.googleapis.com/auth/calendar",
-          client_id : dav.sync.prefSettings.getCharPref("OAuth2_ClientID"),
-          client_secret : dav.sync.prefSettings.getCharPref("OAuth2_ClientSecret"),
-        }
-        break;
-      
-      default:
-        return null;
-    }
-    
-    let oauth = new OAuth2(config.base_uri + "oauth2/auth", config.base_uri + "oauth2/token", config.scope, config.client_id, config.client_secret);
-    oauth.requestWindowFeatures = "chrome,private,centerscreen,width=500,height=750";
-
-    //the v2 endpoints are different and would need manual override
-    //oauth.authURI =
-    //oauth.tokenURI = 
-    oauth.extraAuthParams = [
-      ["access_type", "offline"],
-      ["prompt", "select_account"],
-      // Does not work with "legacy" clients like Thunderbird, do not know why, 
-      // also the OAuth UI looks different from Firefox.
-      //["login_hint", "test@gmail.com"],
-    ];
-    
-    // Storing the accountID as part of the URI has multiple benefits:
-    // - it does not get lost during offline support disable/enable
-    // - we can connect multiple google accounts without running into same-url-issue of shared calendars
-    // - if called from lightning, we do not need to do an expensive url search to get the accountID
-    let accountID = uri.username || ((configObject && configObject.hasOwnProperty("accountID")) ? configObject.accountID : null);
-
-    let accountData = null;
-    try {
-      accountData = new TbSync.AccountData(accountID);
-    } catch (e) {};
-    
-    if (configObject && configObject.hasOwnProperty("accountname")) {
-      oauth.requestWindowTitle = "TbSync account <" + configObject.accountname + "> requests authorization.";
-    } else if (accountData) {
-      oauth.requestWindowTitle = "TbSync account <" + accountData.getAccountProperty("accountname") + "> requests authorization.";
-    } else {
-      oauth.requestWindowTitle = "A TbSync account requests authorization.";
-    }      
-
-    
-    
-    
-    /* Adding custom methods to the oauth object */ 
-
-    // Similar to tbSyncDavCalendar.oauthConnect(), but true async.
-    oauth.asyncConnect = async function(rv) {
-      let self = this;
-      rv.error = "";
-      rv.tokens = "";
-
-      // If multiple resources need to authenticate they will all end here, even though they
-      // might share the same token. Due to the async nature, each process will refresh
-      // "its own" token again, which is not needed. We force clear the token here and each
-      // final connect process will actually check the acccessToken and abort the refresh, 
-      // if it is already there, generated by some other process. 
-      if (self.accessToken) self.accessToken = "";
-      
-      try {
-        await new Promise(function(resolve, reject) {
-          // refresh = false will do nothing and resolve immediately, if an accessToken
-          // exists already, which must have been generated by another process, as
-          // we cleared it beforehand.
-          self.connect(resolve, reject, /* with UI */ true, /* refresh */ false);
-        });
-        rv.tokens = self.tokens;
-        return true;
-      } catch (e) {
-        rv.error = e;
-      }
-      
-      try {
-        switch (JSON.parse(rv.error).error) {
-          case "invalid_grant":
-            self.accessToken = "";
-            self.refreshToken = "";
-            return true;
-
-          case "cancelled": 
-            rv.error = "OAuthAbortError"; 
-            break;
-          
-          default:
-            rv.error = "OAuthServerError::"+rv.error; 
-            break;
-        }
-      } catch (e) {
-        rv.error = "OAuthServerError::"+rv.error; 
-      }
-      return false;
-    };
-
-    oauth.isExpired = function() {
-      const OAUTH_GRACE_TIME = 30 * 1000;
-      return (this.tokenExpires - OAUTH_GRACE_TIME < new Date().getTime());
-    };
-    
-    const OAUTHVALUES = [
-      ["access", "", "accessToken"], 
-      ["refresh", "", "refreshToken"], 
-      ["expires", Number.MAX_VALUE, "tokenExpires"],
-    ];
-        
-    // returns a JSON string containing all the oauth values
-    Object.defineProperty(oauth, "tokens", {
-      get: function() {
-        let tokensObj = {};
-        for (let oauthValue of OAUTHVALUES) {
-          // use the system value or if not defined the default
-          tokensObj[oauthValue[0]] = this[oauthValue[2]] || oauthValue[1];
-        }
-        return JSON.stringify(tokensObj);
-      },
-      enumerable: true,
-    });
-    
-    if (accountData) {      
-      // authData allows us to access the password manager values belonging to this account/calendar
-      // simply by authdata.username and authdata.password
-      oauth.authData = TbSync.providers.dav.network.getAuthData(accountData);        
-
-      oauth.parseAndSanitizeTokenString = function(tokenString) {
-        let _tokensObj = {};
-        try {
-          _tokensObj = JSON.parse(tokenString);
-        } catch (e) {}
-
-        let tokensObj = {};
-        for (let oauthValue of OAUTHVALUES) {
-          // use the provided value or if not defined the default
-          tokensObj[oauthValue[0]] = (_tokensObj && _tokensObj.hasOwnProperty(oauthValue[0]))
-            ? _tokensObj[oauthValue[0]]
-            : oauthValue[1];
-        }
-        return tokensObj;
-      };
-      
-      // Define getter/setter to act on the password manager password value belonging to this account/calendar
-      for (let oauthValue of OAUTHVALUES) {
-        Object.defineProperty(oauth, oauthValue[2], {
-          get: function() {
-            return this.parseAndSanitizeTokenString(this.authData.password)[oauthValue[0]];
-          },
-          set: function(val) {
-            let tokens = this.parseAndSanitizeTokenString(this.authData.password);
-            let valueChanged = (val != tokens[oauthValue[0]])
-            if (valueChanged) {
-              tokens[oauthValue[0]] = val;
-              this.authData.updateLoginData(this.authData.username, JSON.stringify(tokens));
-            }
-          },
-          enumerable: true,
-        });
-      }
-    }
-    
-    return oauth;
-  },
-
-  getOAuthValue: function(currentTokenString, type = "access") {
-    try {
-      let tokens = JSON.parse(currentTokenString);
-      if (tokens.hasOwnProperty(type))
-        return tokens[type];
-    } catch (e) {
-      //NOOP
-    }
-    return "";
-  },
-  
   ConnectionData: class {
     constructor(data) {            
       this._password = "";
@@ -405,21 +212,6 @@ var network = {
 
       connectionData.url = url;
 
-      connectionData.oauthObj = dav.network.getOAuthObj(connectionData.url, { username: connectionData.username, accountID });
-      // Check OAUTH situation before connecting.
-      if (connectionData.oauthObj && (!connectionData.oauthObj.accessToken || connectionData.oauthObj.isExpired())) {
-          let rv = {}
-          if (connectionData.accountData) {
-            connectionData.accountData.syncData.setSyncState("oauthprompt");
-          }
-
-          if (await connectionData.oauthObj.asyncConnect(rv)) {
-            connectionData.password = rv.tokens;
-          } else {
-            throw dav.sync.finish("error", rv.error);                                
-          }
-      }
-
       // Restore original syncstate before open the connection
       if (connectionData.accountData && currentSyncState != connectionData.accountData.syncData.getSyncState().state) {
         connectionData.accountData.syncData.setSyncState(currentSyncState);
@@ -440,30 +232,25 @@ var network = {
           
           // Prompt, if connection belongs to an account (and not from the create wizard)
           if (connectionData.accountData) {
-            if (connectionData.oauthObj) {
-              connectionData.oauthObj.accessToken = "";
-              retry = true;
-            } else {
-              let promptData = {
-                windowID: "auth:" + connectionData.accountData.accountID,
-                accountname: connectionData.accountData.getAccountProperty("accountname"),
-                usernameLocked: connectionData.accountData.isConnected(),
-                username: connectionData.username,                
-              }
-              connectionData.accountData.syncData.setSyncState("passwordprompt");
+            let promptData = {
+              windowID: "auth:" + connectionData.accountData.accountID,
+              accountname: connectionData.accountData.getAccountProperty("accountname"),
+              usernameLocked: connectionData.accountData.isConnected(),
+              username: connectionData.username,
+            }
+            connectionData.accountData.syncData.setSyncState("passwordprompt");
 
-              credentials = await TbSync.passwordManager.asyncPasswordPrompt(promptData, dav.openWindows);
-              if (credentials) {
-                // update login data
-                dav.network.getAuthData(connectionData.accountData).updateLoginData(credentials.username, credentials.password);
-                // update connection data
-                connectionData.username = credentials.username;
-                connectionData.password = credentials.password;
-                retry = true;
-              }
-            }              
+            credentials = await TbSync.passwordManager.asyncPasswordPrompt(promptData, dav.openWindows);
+            if (credentials) {
+              // update login data
+              dav.network.getAuthData(connectionData.accountData).updateLoginData(credentials.username, credentials.password);
+              // update connection data
+              connectionData.username = credentials.username;
+              connectionData.password = credentials.password;
+              retry = true;
+            }
           }
-                    
+
           if (!retry) {
             throw r.passwordError;
           }
@@ -514,11 +301,6 @@ var network = {
 
       req.setRequestHeader("User-Agent", dav.sync.prefSettings.getCharPref("clientID.useragent"));
 
-      // If this is one of the servers which we use OAuth for, add the bearer token.
-      if (connectionData.oauthObj) {
-        req.setRequestHeader("Authorization", "Bearer " +  dav.network.getOAuthValue(connectionData.password, "access"));
-      }
-      
       req.realmCallback = function(username, realm, host) {
         // Store realm, needed later to setup lightning passwords.
         TbSync.dump("Found CalDAV authRealm for <"+host+">", realm);
